==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/mi-NZ/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Whakaaetia te Puku Whakamuri Taonga',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Arotakehia nga rawa mo te whakakore nui i raro. Kia mukua, ka taea te whakahoki mai i enei taonga, engari kaore i te hono atu ki nga kaiwhakamahi e tukuna ana ki a raatau.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Kei te tata koe ki te muku: te hua moni rawa.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Kaupapa Whakatairanga Nui',
    'bulk_update_help'	=> 'Ko tenei puka ka taea e koe te whakahou i nga hua maha i te wa kotahi. Whakakiia nga mara e hiahia ana koe ki te huri. Ko nga mara katoa e mahue ana ka noho tonu.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Kua aroahia ki te',
    'checkout_date'		=> 'Rā Rārangi',
    'checkin_date'		=> 'Rangi Titiro',
    'checkout_to'		=> 'Whakaritea ki',
    'cost'				=> 'Utu Hokona',
    'create'			=> 'Waihanga Ahua',
    'date'				=> 'Raa Hokona',
    'depreciation'	    => 'Te whakahekenga moni',
    'depreciates_on'	=> 'Whakapaihia ana i runga',
    'default_location'	=> 'Tauwāhi Taunoa',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL Rā',
    'eol_rate'			=> 'EOL Tau',
    'expected_checkin'  => 'Ko te Whakataunga Whakataunga Whakaaro',
    'expires'			=> 'Ka puta',
    'fully_depreciated'	=> 'Kua tino tohaina',
    'help_checkout'		=> 'Ki te hiahia koe ki te tautapa i tenei taonga tonu, tīpakohia "Ka rite ki te Whakamahia" mai i te rārangi mana i runga.',
    'mac_address'		=> 'Wāhitau MAC',
    'manufacturer'		=> 'Kaihanga',
    'model'				=> 'Tauira',
    'months'			=> 'marama',
    'name'				=> 'Ingoa Ahua',
    'notes'				=> 'Tuhipoka',
    'order'				=> 'Tau Tau',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Ka taea e nga kaiwhakamahi te tono mo tenei taonga',
    'select_statustype'	=> 'Tīpakohia te Momo Tūnga',
    'serial'			=> 'Waea',
    'status'			=> 'Tūnga',
    'tag'				=> 'Tae Taonga',
    'update'			=> 'Te Whakahou Ahua',
    'warranty'			=> 'Te tiwhikete',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'tau',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/mi-NZ/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Whakaaetia te Puku Whakamuri Taonga',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Arotakehia nga rawa mo te whakakore nui i raro. Kia mukua, ka taea te whakahoki mai i enei taonga, engari kaore i te hono atu ki nga kaiwhakamahi e tukuna ana ki a raatau.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'Kei te tata koe ki te muku: te hua moni rawa.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Kaupapa Whakatairanga Nui',
    'bulk_update_help'	=> 'Ko tenei puka ka taea e koe te whakahou i nga hua maha i te wa kotahi. Whakakiia nga mara e hiahia ana koe ki te huri. Ko nga mara katoa e mahue ana ka noho tonu.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Kua aroahia ki te',
    'checkout_date'		=> 'Rā Rārangi',
    'checkin_date'		=> 'Rangi Titiro',
    'checkout_to'		=> 'Whakaritea ki',
    'cost'				=> 'Utu Hokona',
    'create'			=> 'Waihanga Ahua',
    'date'				=> 'Raa Hokona',
    'depreciation'	    => 'Te whakahekenga moni',
    'depreciates_on'	=> 'Whakapaihia ana i runga',
    'default_location'	=> 'Tauwāhi Taunoa',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL Rā',
    'eol_rate'			=> 'EOL Tau',
    'expected_checkin'  => 'Ko te Whakataunga Whakataunga Whakaaro',
    'expires'			=> 'Ka puta',
    'fully_depreciated'	=> 'Kua tino tohaina',
    'help_checkout'		=> 'Ki te hiahia koe ki te tautapa i tenei taonga tonu, tīpakohia "Ka rite ki te Whakamahia" mai i te rārangi mana i runga.',
    'mac_address'		=> 'Wāhitau MAC',
    'manufacturer'		=> 'Kaihanga',
    'model'				=> 'Tauira',
    'months'			=> 'marama',
    'name'				=> 'Ingoa Ahua',
    'notes'				=> 'Tuhipoka',
    'order'				=> 'Tau Tau',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Ka taea e nga kaiwhakamahi te tono mo tenei taonga',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Tīpakohia te Momo Tūnga',
    'serial'			=> 'Waea',
    'status'			=> 'Tūnga',
    'tag'				=> 'Tae Taonga',
    'update'			=> 'Te Whakahou Ahua',
    'warranty'			=> 'Te tiwhikete',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'tau',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];
